﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using System.Windows.Forms;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.DataImporter.Data.Command {
  [StorableClass]
  public class InsertRowCommand : ColumnGroupCommandBase {
    [Storable]
    private int position;

    private ICollection<int> oldSortedColumnIndices;
    private IEnumerable<SortOrder> oldSortOrder;

    private InsertRowCommand()
      : base(null, string.Empty) {
    }

    public InsertRowCommand(DataSet dataSet, string columnGroupName, int position)
      : base(dataSet, columnGroupName) {
      this.position = position;
    }

    public override void Execute() {
      base.Execute();
      ColumnGroup.InsertRow(position, ColumnGroup.GetEmptyRow());
      oldSortedColumnIndices = new List<int>(ColumnGroup.SortedColumnIndexes);
      oldSortOrder = ColumnGroup.SortOrdersForColumns.ToList();
      ColumnGroup.FireChanged();
      this.ColumnGroup = null;
    }

    public override void UndoExecute() {
      base.UndoExecute();
      ColumnGroup.DeleteRow(position);
      ColumnGroup.SortOrdersForColumns = oldSortOrder;
      ColumnGroup.SortedColumnIndexes = oldSortedColumnIndices;
      oldSortedColumnIndices = null;
      oldSortOrder = null;
      ColumnGroup.FireChanged();
      this.ColumnGroup = null;
    }

    public override string Description {
      get { return "Empty row inserted"; }
    }
  }
}
